Function sp_io::crypto::sr25519_public_keys
source · pub fn sr25519_public_keys(id: KeyTypeId) -> Vec<Public>Expand description
Returns all sr25519 public keys for the given key id from the keystore.
pub fn sr25519_public_keys(id: KeyTypeId) -> Vec<Public>Returns all sr25519 public keys for the given key id from the keystore.